==> cognito-1.60.0-sources.jar: software/amazon/awscdk/services/cognito/CognitoDomainOptions.java <==
package software.amazon.awscdk.services.cognito;

/**
 * Options while specifying a cognito prefix domain.
 * <p>
 * EXPERIMENTAL
 * <p>
 * @see https://docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-pools-assign-domain-prefix.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:23.705Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cognito.$Module.class, fqn = "@aws-cdk/aws-cognito.CognitoDomainOptions")
@software.amazon.jsii.Jsii.Proxy(CognitoDomainOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface CognitoDomainOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * The prefix to the Cognito hosted domain name that will be associated with the user pool.
     * <p>
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.String getDomainPrefix();

    /**
     * @return a {@link Builder} of {@link CognitoDomainOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CognitoDomainOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<CognitoDomainOptions> {
        private java.lang.String domainPrefix;

        /**
         * Sets the value of {@link CognitoDomainOptions#getDomainPrefix}
         * @param domainPrefix The prefix to the Cognito hosted domain name that will be associated with the user pool. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder domainPrefix(java.lang.String domainPrefix) {
            this.domainPrefix = domainPrefix;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CognitoDomainOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public CognitoDomainOptions build() {
            return new Jsii$Proxy(domainPrefix);
        }
    }

    /**
     * An implementation for {@link CognitoDomainOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CognitoDomainOptions {
        private final java.lang.String domainPrefix;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.domainPrefix = this.jsiiGet("domainPrefix", java.lang.String.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final java.lang.String domainPrefix) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.domainPrefix = java.util.Objects.requireNonNull(domainPrefix, "domainPrefix is required");
        }

        @Override
        public java.lang.String getDomainPrefix() {
            return this.domainPrefix;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("domainPrefix", om.valueToTree(this.getDomainPrefix()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-cognito.CognitoDomainOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CognitoDomainOptions.Jsii$Proxy that = (CognitoDomainOptions.Jsii$Proxy) o;

            return this.domainPrefix.equals(that.domainPrefix);
        }

        @Override
        public int hashCode() {
            int result = this.domainPrefix.hashCode();
            return result;
        }
    }
}

==> cognito-1.93.0-sources.jar: software/amazon/awscdk/services/cognito/CognitoDomainOptions.java <==
package software.amazon.awscdk.services.cognito;

/**
 * Options while specifying a cognito prefix domain.
 * <p>
 * @see https://docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-pools-assign-domain-prefix.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:52.470Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cognito.$Module.class, fqn = "@aws-cdk/aws-cognito.CognitoDomainOptions")
@software.amazon.jsii.Jsii.Proxy(CognitoDomainOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CognitoDomainOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * The prefix to the Cognito hosted domain name that will be associated with the user pool.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getDomainPrefix();

    /**
     * @return a {@link Builder} of {@link CognitoDomainOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CognitoDomainOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CognitoDomainOptions> {
        private java.lang.String domainPrefix;

        /**
         * Sets the value of {@link CognitoDomainOptions#getDomainPrefix}
         * @param domainPrefix The prefix to the Cognito hosted domain name that will be associated with the user pool. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder domainPrefix(java.lang.String domainPrefix) {
            this.domainPrefix = domainPrefix;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CognitoDomainOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CognitoDomainOptions build() {
            return new Jsii$Proxy(domainPrefix);
        }
    }

    /**
     * An implementation for {@link CognitoDomainOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CognitoDomainOptions {
        private final java.lang.String domainPrefix;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.domainPrefix = software.amazon.jsii.Kernel.get(this, "domainPrefix", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.String domainPrefix) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.domainPrefix = java.util.Objects.requireNonNull(domainPrefix, "domainPrefix is required");
        }

        @Override
        public final java.lang.String getDomainPrefix() {
            return this.domainPrefix;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("domainPrefix", om.valueToTree(this.getDomainPrefix()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-cognito.CognitoDomainOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CognitoDomainOptions.Jsii$Proxy that = (CognitoDomainOptions.Jsii$Proxy) o;

            return this.domainPrefix.equals(that.domainPrefix);
        }

        @Override
        public final int hashCode() {
            int result = this.domainPrefix.hashCode();
            return result;
        }
    }
}
